GenericRequest<T> class

Constructors

GenericRequest({required T fromMap(dynamic), required RequestApi method})
GenericRequest.source({required RequestApi method})

Properties

fromMap → T Function(dynamic)
final
hashCode → int
The hash code for this object.
no setterinherited
method → RequestApi
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

errorModel(dynamic response, String statusMessage, ExpectType expectType) → ServerException
getBytes() → Future<Uint8List>
getList() → Future<List<T>>
getObject() → Future<T>
getResponse() → Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

init({required String keyData}) → void