FreeMonad<F> class

Inheritance
Mixed-in types

Constructors

FreeMonad()

Properties

hashCode → int
The hash code for this object.
no setterinherited
nothing → Free<F, dynamic>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ap<A, B>(Free<F, dynamic> fa, Free<F, dynamic> ff) → Free<F, dynamic>
inherited
bind<A, B>(covariant Free<F, A> fa, covariant Function1<A, Free<F, B>> f) → Free<F, B>
override
composeF(Functor G) → Functor<Free<F, dynamic>>
inherited
join(Free<F, dynamic> ffa) → Free<F, dynamic>
inherited
map<A, B>(Free<F, dynamic> fa, B f(A a)) → Free<F, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pure<A>(A a) → Free<F, A>
override
strengthL<A, B>(Free<F, dynamic> fa, B b) → Free<F, dynamic>
inherited
strengthR<A, B>(Free<F, dynamic> fa, B b) → Free<F, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited