Lens<AIn, AOut, BIn, BOut> class

Constructors

Lens(Function1<AIn, BOut> _getter, Function2<AIn, BIn, AOut> _setter)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

andThen<CIn, COut>(Lens<BOut, BIn, CIn, COut> otherLens) → Lens<AIn, AOut, CIn, COut>
get(AIn a) → BOut
modify(AIn a, Function1<BOut, BIn> f) → AOut
modifyC(Function1<BOut, BIn> f) → Function1<AIn, AOut>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(AIn a, BIn b) → AOut
setC(BIn b) → Function1<AIn, AOut>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited