ListTraversableMonadPlus class

Inheritance
Mixed-in types

Constructors

ListTraversableMonadPlus()

Properties

hashCode → int
The hash code for this object.
no setterinherited
nothing → List
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all(List fa, bool f(dynamic a)) → bool
inherited
any(List fa, bool f(dynamic a)) → bool
inherited
ap<A, B>(List fa, List ff) → List
inherited
appendElement<A>(List fa, A a) → List
inherited
bind<A, B>(covariant List<A> fa, covariant Function1<A, List<B>> f) → List<B>
override
composeF(Functor G) → Functor<List>
inherited
concatenate<A>(Monoid<A> mi, List fa) → A
inherited
concatenateO<A>(Semigroup<A> si, List fa) → Option<A>
inherited
empty<A>() → List<A>
override
filter(List fa, bool predicate(dynamic a)) → List
inherited
foldLeft<A, B>(List fa, B z, B f(B previous, A a)) → B
inherited
foldLeftWithIndex<A, B>(List fa, B z, B f(B previous, int i, A a)) → B
inherited
foldMap<A, B>(Monoid<B> bMonoid, covariant List<A> fa, B f(A a)) → B
override
foldMapO<A, B>(Semigroup<B> si, List fa, B f(A a)) → Option<B>
inherited
foldRight<A, B>(List fa, B z, B f(A a, B previous)) → B
inherited
foldRightWithIndex<A, B>(List fa, B z, B f(int i, dynamic a, B previous)) → B
inherited
intercalate<A>(Monoid<A> mi, List fa, A a) → A
inherited
join(List ffa) → List
inherited
length(List fa) → int
inherited
map<A, B>(List fa, B f(A a)) → List
inherited
maximum<A>(Order<A> oa, List fa) → Option<A>
inherited
minimum<A>(Order<A> oa, List fa) → Option<A>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partition<A>(List fa, bool f(A a)) → Tuple2<List, List>
inherited
plus<A>(covariant List<A> f1, covariant List<A> f2) → List<A>
override
prependElement<A>(List fa, A a) → List
inherited
pure<A>(A a) → List<A>
override
reverse(List fa) → List
inherited
strengthL<A, B>(List fa, B b) → List
inherited
strengthR<A, B>(List fa, B b) → List
inherited
toString() → String
A string representation of this object.
inherited
unite(List fa, Foldable gFoldable) → List
inherited
where(List fa, bool predicate(dynamic a)) → List
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited