OptionLens<A, B> class

Inheritance

Constructors

OptionLens(Function1<A, Option<B>> getter, Function2<A, B, Option<A>> setter)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

andThen<CIn, COut>(Lens<Option<B>, B, CIn, COut> otherLens) → Lens<A, Option<A>, CIn, COut>
inherited
get(A a) → Option<B>
inherited
modify(A a, Function1<Option<B>, B> f) → Option<A>
inherited
modifyC(Function1<Option<B>, B> f) → Function1<A, Option<A>>
inherited
modifyO(A a, Function1<B, B> f) → Option<A>
modifyOC(Function1<B, B> f) → Function1<A, Option<A>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
oAndThen<C>(Lens<B, B, C, C> otherLens) → OptionLens<A, C>
oAndThenO<C>(OptionLens<B, C> otherLens) → OptionLens<A, C>
set(A a, B b) → Option<A>
inherited
setC(B b) → Function1<A, Option<A>>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited